@@ -17,6 +17,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
@@ -26,25 +30,24 @@
 #include "trg-destination-combo.h"
 #include "util.h"
 
-G_DEFINE_TYPE(TrgDestinationCombo, trg_destination_combo,
-              GTK_TYPE_COMBO_BOX)
-#define TRG_DESTINATION_COMBO_GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRG_TYPE_DESTINATION_COMBO, TrgDestinationComboPrivate))
-typedef struct _TrgDestinationComboPrivate TrgDestinationComboPrivate;
+struct _TrgDestinationCombo {
+    GtkComboBox parent_instance;
+};
 
-struct _TrgDestinationComboPrivate {
+typedef struct {
     TrgClient *client;
     gchar *last_selection;
-    GtkWidget *entry;
-    GtkCellRenderer *text_renderer;
-};
+} TrgDestinationComboPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE(TrgDestinationCombo, trg_destination_combo,
+              GTK_TYPE_COMBO_BOX)
 
 enum {
     PROP_0, PROP_CLIENT, PROP_LAST_SELECTION
 };
 
 enum {
-    DEST_DEFAULT, DEST_LABEL, DEST_EXISTING, DEST_USERADD
+    DEST_DEFAULT, DEST_LABEL, DEST_EXISTING
 };
 
 enum {
@@ -54,7 +57,7 @@ enum {
 static void trg_destination_combo_finalize(GObject * object)
 {
     TrgDestinationComboPrivate *priv =
-        TRG_DESTINATION_COMBO_GET_PRIVATE(object);
+        trg_destination_combo_get_instance_private(TRG_DESTINATION_COMBO(object));
     g_free(priv->last_selection);
 }
 
@@ -64,7 +67,7 @@ trg_destination_combo_get_property(GObject * object,
                                    GValue * value, GParamSpec * pspec)
 {
     TrgDestinationComboPrivate *priv =
-        TRG_DESTINATION_COMBO_GET_PRIVATE(object);
+        trg_destination_combo_get_instance_private(TRG_DESTINATION_COMBO(object));
     switch (property_id) {
     case PROP_CLIENT:
         g_value_set_pointer(value, priv->client);
@@ -85,7 +88,7 @@ trg_destination_combo_set_property(GObject * object,
                                    GParamSpec * pspec)
 {
     TrgDestinationComboPrivate *priv =
-        TRG_DESTINATION_COMBO_GET_PRIVATE(object);
+        trg_destination_combo_get_instance_private(TRG_DESTINATION_COMBO(object));
     switch (property_id) {
     case PROP_CLIENT:
         priv->client = g_value_get_pointer(value);
@@ -115,7 +118,7 @@ static gboolean g_slist_str_set_add(GSList ** list, const gchar * string)
 void trg_destination_combo_save_selection(TrgDestinationCombo * combo_box)
 {
     TrgDestinationComboPrivate *priv =
-        TRG_DESTINATION_COMBO_GET_PRIVATE(combo_box);
+        trg_destination_combo_get_instance_private(combo_box);
     GtkTreeIter iter;
 
     if (priv->last_selection
@@ -126,47 +129,16 @@ void trg_destination_combo_save_selection(TrgDestinationCombo * combo_box)
         TrgPrefs *prefs = trg_client_get_prefs(priv->client);
         gchar *text;
 
-        gtk_tree_model_get(model, &iter, DEST_COLUMN_LABEL, &text, -1);
+        gtk_tree_model_get(model, &iter, DEST_COLUMN_DIR, &text, -1);
         trg_prefs_set_string(prefs, priv->last_selection, text,
                              TRG_PREFS_CONNECTION);
         g_free(text);
     }
 }
 
-static void
-gtk_combo_box_entry_active_changed(GtkComboBox * combo_box,
-                                   gpointer user_data)
+static inline GtkEntry *trg_destination_combo_get_entry(TrgDestinationCombo * combo)
 {
-    GtkTreeModel *model;
-    GtkTreeIter iter;
-    gboolean editableEntry = TRUE;
-
-    if (gtk_combo_box_get_active_iter(combo_box, &iter)) {
-        GtkEntry *entry =
-            trg_destination_combo_get_entry(TRG_DESTINATION_COMBO
-                                            (combo_box));
-
-        if (entry) {
-            GValue value = { 0, };
-            guint type;
-
-            model = gtk_combo_box_get_model(combo_box);
-
-            gtk_tree_model_get_value(model, &iter, DEST_COLUMN_LABEL,
-                                     &value);
-            gtk_tree_model_get(model, &iter, DEST_COLUMN_TYPE, &type, -1);
-
-            g_object_set_property(G_OBJECT(entry), "text", &value);
-            g_value_unset(&value);
-
-            if (type == DEST_LABEL)
-                editableEntry = FALSE;
-        }
-    }
-    gtk_editable_set_editable(GTK_EDITABLE
-                              (trg_destination_combo_get_entry
-                               (TRG_DESTINATION_COMBO(combo_box))),
-                              editableEntry);
+    return GTK_ENTRY(gtk_bin_get_child(GTK_BIN(combo)));
 }
 
 gboolean trg_destination_combo_has_text(TrgDestinationCombo * combo)
@@ -177,35 +149,12 @@ gboolean trg_destination_combo_has_text(TrgDestinationCombo * combo)
     return strlen(text) > 0;
 }
 
-GtkEntry *trg_destination_combo_get_entry(TrgDestinationCombo * combo)
-{
-    TrgDestinationComboPrivate *priv =
-        TRG_DESTINATION_COMBO_GET_PRIVATE(combo);
-    return GTK_ENTRY(priv->entry);
-}
-
-static void
-add_entry_cb(GtkEntry * entry,
-             GtkEntryIconPosition icon_pos,
-             GdkEvent * event, gpointer user_data)
-{
-    GtkComboBox *combo = GTK_COMBO_BOX(user_data);
-    GtkTreeModel *model = gtk_combo_box_get_model(combo);
-    GtkTreeIter iter;
-
-    gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter,
-                                      INT_MAX, DEST_COLUMN_LABEL, "",
-                                      DEST_COLUMN_DIR, "",
-                                      DEST_COLUMN_TYPE, DEST_USERADD, -1);
-    gtk_combo_box_set_active_iter(combo, &iter);
-}
-
 struct findDupeArg {
     const gchar *dir;
     gboolean isDupe;
 };
 
-gboolean
+static gboolean
 trg_destination_combo_insert_check_dupe_foreach(GtkTreeModel * model,
                                                 GtkTreePath *
                                                 path G_GNUC_UNUSED,
@@ -222,12 +171,11 @@ trg_destination_combo_insert_check_dupe_foreach(GtkTreeModel * model,
 static void
 trg_destination_combo_insert(GtkComboBox * box,
                              const gchar * label,
-                             const gchar * dir, guint type,
-                             const gchar * lastDestination)
+                             const gchar * dir,
+                             guint         type)
 {
     GtkTreeModel *model = gtk_combo_box_get_model(box);
     gchar *comboLabel;
-    GtkTreeIter iter;
 
     if (type == DEST_EXISTING) {
         struct findDupeArg args;
@@ -244,110 +192,88 @@ trg_destination_combo_insert(GtkComboBox * box,
     comboLabel =
         label ? g_strdup_printf("%s (%s)", label, dir) : g_strdup(dir);
 
-    gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter,
-                                      INT_MAX, DEST_COLUMN_LABEL,
-                                      comboLabel, DEST_COLUMN_DIR, dir,
+    gtk_list_store_insert_with_values(GTK_LIST_STORE(model), NULL, -1,
+                                      DEST_COLUMN_LABEL, comboLabel,
+                                      DEST_COLUMN_DIR, dir,
                                       DEST_COLUMN_TYPE, type, -1);
-
-    if (lastDestination && !g_strcmp0(lastDestination, comboLabel))
-        gtk_combo_box_set_active_iter(box, &iter);
-
     g_free(comboLabel);
 }
 
-static GObject *trg_destination_combo_constructor(GType type,
-                                                  guint
-                                                  n_construct_properties,
-                                                  GObjectConstructParam *
-                                                  construct_params)
+gchar *trg_destination_combo_get_dir(TrgDestinationCombo * combo)
 {
-    GObject *object = G_OBJECT_CLASS
-        (trg_destination_combo_parent_class)->constructor(type,
-                                                          n_construct_properties,
-                                                          construct_params);
-    TrgDestinationComboPrivate *priv =
-        TRG_DESTINATION_COMBO_GET_PRIVATE(object);
+    GtkTreeModel *model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+    GtkTreeIter iter;
 
+    if (gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) {
+        gchar *value;
+        guint type;
+
+        gtk_tree_model_get(model, &iter, DEST_COLUMN_TYPE, &type, -1);
+
+        if (type == DEST_LABEL) {
+            gtk_tree_model_get(model, &iter, DEST_COLUMN_DIR, &value, -1);
+            return value;
+        }
+    }
+
+    return
+        g_strdup(gtk_entry_get_text
+                 (trg_destination_combo_get_entry(combo)));
+}
+
+static void
+load_directory_model(TrgDestinationCombo *self)
+{
+    TrgDestinationComboPrivate *priv = trg_destination_combo_get_instance_private(self);
     TrgClient *client = priv->client;
     TrgPrefs *prefs = trg_client_get_prefs(client);
 
     GSList *dirs = NULL, *sli;
     GList *li, *list;
-    GtkTreeRowReference *rr;
-    GtkTreeModel *model;
-    GtkTreePath *path;
-    GtkListStore *comboModel;
+
     JsonArray *savedDestinations;
     gchar *defaultDir;
-    gchar *lastDestination = NULL;
-
-    comboModel = gtk_list_store_new(N_DEST_COLUMNS, G_TYPE_STRING,
-                                    G_TYPE_STRING, G_TYPE_UINT);
-    gtk_combo_box_set_model(GTK_COMBO_BOX(object),
-                            GTK_TREE_MODEL(comboModel));
-    g_object_unref(comboModel);
-
-    g_signal_connect(object, "changed",
-                     G_CALLBACK(gtk_combo_box_entry_active_changed), NULL);
-
-    priv->entry = gtk_entry_new();
-    gtk_container_add(GTK_CONTAINER(object), priv->entry);
-
-    priv->text_renderer = gtk_cell_renderer_text_new();
-    gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(object),
-                               priv->text_renderer, TRUE);
-
-    gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(object),
-                                   priv->text_renderer, "text", 0, NULL);
-
-    g_slist_foreach(dirs, (GFunc) g_free, NULL);
-    g_slist_free(dirs);
-
-    gtk_entry_set_icon_from_stock(GTK_ENTRY(priv->entry),
-                                  GTK_ENTRY_ICON_SECONDARY,
-                                  GTK_STOCK_CLEAR);
-
-    g_signal_connect(priv->entry, "icon-release",
-                     G_CALLBACK(add_entry_cb), object);
 
+    /* Add default dir */
     defaultDir =
         g_strdup(session_get_download_dir(trg_client_get_session(client)));
     rm_trailing_slashes(defaultDir);
 
+    trg_destination_combo_insert(GTK_COMBO_BOX(self),
+                                 NULL,
+                                 defaultDir, DEST_DEFAULT);
+    g_free (defaultDir);
+
+
+    /* Add saved dirs */
     savedDestinations =
         trg_prefs_get_array(prefs, TRG_PREFS_KEY_DESTINATIONS,
                             TRG_PREFS_CONNECTION);
-
-    if (priv->last_selection)
-        lastDestination = trg_prefs_get_string(prefs, priv->last_selection,
-                                               TRG_PREFS_CONNECTION);
-
-    trg_destination_combo_insert(GTK_COMBO_BOX(object),
-                                 NULL,
-                                 defaultDir, DEST_DEFAULT,
-                                 lastDestination);
-    gtk_combo_box_set_active(GTK_COMBO_BOX(object), 0);
-
     if (savedDestinations) {
         list = json_array_get_elements(savedDestinations);
         if (list) {
             for (li = list; li; li = g_list_next(li)) {
                 JsonObject *obj =
                     json_node_get_object((JsonNode *) li->data);
-                trg_destination_combo_insert(GTK_COMBO_BOX(object),
+                trg_destination_combo_insert(GTK_COMBO_BOX(self),
                                              json_object_get_string_member
-                                             (obj, TRG_PREFS_SUBKEY_LABEL),
-                                             json_object_get_string_member
-                                             (obj,
-                                              TRG_PREFS_KEY_DESTINATIONS_SUBKEY_DIR),
-                                             DEST_LABEL, lastDestination);
+                                                 (obj, TRG_PREFS_SUBKEY_LABEL),
+                                            json_object_get_string_member
+                                                 (obj, TRG_PREFS_KEY_DESTINATIONS_SUBKEY_DIR),
+                                             DEST_LABEL);
             }
             g_list_free(list);
         }
     }
 
+
+    /* Add all previously used download dirs */
     list = g_hash_table_get_values(trg_client_get_torrent_table(client));
     for (li = list; li; li = g_list_next(li)) {
+        GtkTreeRowReference *rr;
+        GtkTreeModel *model;
+        GtkTreePath *path;
+
         rr = (GtkTreeRowReference *) li->data;
         model = gtk_tree_row_reference_get_model(rr);
         path = gtk_tree_row_reference_get_path(rr);
@@ -372,38 +298,48 @@ static GObject *trg_destination_combo_constructor(GType type,
     }
 
     for (sli = dirs; sli; sli = g_slist_next(sli))
-        trg_destination_combo_insert(GTK_COMBO_BOX(object),
+        trg_destination_combo_insert(GTK_COMBO_BOX(self),
                                      NULL,
                                      (gchar *) sli->data,
-                                     DEST_EXISTING, lastDestination);
+                                     DEST_EXISTING);
 
+    g_slist_free_full (dirs, g_free);
     g_list_free(list);
-    g_free(defaultDir);
-    g_free(lastDestination);
-
-    return object;
 }
 
-gchar *trg_destination_combo_get_dir(TrgDestinationCombo * combo)
+static void set_text_column(GtkCellLayout *layout, guint col)
 {
-    GtkTreeModel *model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
-    GtkTreeIter iter;
+    GList *cells = gtk_cell_layout_get_cells (layout);
+    g_assert (cells != NULL);
+    gtk_cell_layout_set_attributes (layout, GTK_CELL_RENDERER(cells->data), "text", col, NULL);
+    g_list_free (cells);
+}
 
-    if (gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) {
-        gchar *value;
-        guint type;
+static void trg_destination_combo_constructed(GObject *object)
+{
+    TrgDestinationCombo *self = TRG_DESTINATION_COMBO (object);
+    TrgDestinationComboPrivate *priv =
+        trg_destination_combo_get_instance_private(self);
+    TrgPrefs *prefs = trg_client_get_prefs(priv->client);
 
-        gtk_tree_model_get(model, &iter, DEST_COLUMN_TYPE, &type, -1);
+    G_OBJECT_CLASS(trg_destination_combo_parent_class)->constructed(object);
 
-        if (type == DEST_LABEL) {
-            gtk_tree_model_get(model, &iter, DEST_COLUMN_DIR, &value, -1);
-            return g_strdup(value);
-        }
+    load_directory_model (self);
+    set_text_column (GTK_CELL_LAYOUT(self), DEST_COLUMN_LABEL);
+
+    /* Must be set after constructed */
+    if (priv->last_selection) {
+        /* Restore any previous selection */
+        char *lastDestination = trg_prefs_get_string(prefs, priv->last_selection,
+                                               TRG_PREFS_CONNECTION);
+        if (!gtk_combo_box_set_active_id (GTK_COMBO_BOX(object), lastDestination))
+            g_warning ("Last selection was not a valid ID");
+        g_free(lastDestination);
+    }
+    else {
+        /* DefaultDir is the first item otherwise */
+        gtk_combo_box_set_active (GTK_COMBO_BOX(object), 0);
     }
-
-    return
-        g_strdup(gtk_entry_get_text
-                 (trg_destination_combo_get_entry(combo)));
 }
 
 static void
@@ -411,27 +347,19 @@ trg_destination_combo_class_init(TrgDestinationComboClass * klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS(klass);
 
-    g_type_class_add_private(klass, sizeof(TrgDestinationComboPrivate));
-
     object_class->get_property = trg_destination_combo_get_property;
     object_class->set_property = trg_destination_combo_set_property;
     object_class->finalize = trg_destination_combo_finalize;
-    object_class->constructor = trg_destination_combo_constructor;
+    object_class->constructed = trg_destination_combo_constructed;
 
     g_object_class_install_property(object_class,
                                     PROP_CLIENT,
                                     g_param_spec_pointer("trg-client",
                                                          "TClient",
                                                          "Client",
-                                                         G_PARAM_READWRITE
-                                                         |
-                                                         G_PARAM_CONSTRUCT_ONLY
-                                                         |
-                                                         G_PARAM_STATIC_NAME
-                                                         |
-                                                         G_PARAM_STATIC_NICK
-                                                         |
-                                                         G_PARAM_STATIC_BLURB));
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_CONSTRUCT_ONLY |
+                                                         G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property(object_class,
                                     PROP_LAST_SELECTION,
@@ -441,19 +369,25 @@ trg_destination_combo_class_init(TrgDestinationComboClass * klass)
                                      "LastSelectionKey", NULL,
                                      G_PARAM_READWRITE |
                                      G_PARAM_CONSTRUCT_ONLY |
-                                     G_PARAM_STATIC_NAME |
-                                     G_PARAM_STATIC_NICK |
-                                     G_PARAM_STATIC_BLURB));
+                                     G_PARAM_STATIC_STRINGS));
 }
 
 static void trg_destination_combo_init(TrgDestinationCombo * self)
 {
+    GtkListStore *store;
+
+    store = gtk_list_store_new(N_DEST_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
+    gtk_combo_box_set_model(GTK_COMBO_BOX(self), GTK_TREE_MODEL(store));
+    gtk_combo_box_set_id_column (GTK_COMBO_BOX(self), DEST_COLUMN_DIR);
+    gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX(self), DEST_COLUMN_LABEL);
+    g_object_unref(store);
 }
 
 GtkWidget *trg_destination_combo_new(TrgClient * client,
                                      const gchar * lastSelectionKey)
 {
     return GTK_WIDGET(g_object_new(TRG_TYPE_DESTINATION_COMBO,
+                                   "has-entry", TRUE,
                                    "trg-client", client,
                                    "last-selection-key", lastSelectionKey,
                                    NULL));
