@@ -422,9 +422,9 @@ static GtkWidget *trg_props_limits_page_new(TrgTorrentPropsDialog * win,
     hig_workarea_add_row(t, &row, _("Torrent priority:"), w, NULL);
 
     if (json_object_has_member(json, FIELD_QUEUE_POSITION)) {
-        w = trg_json_widget_spin_new(&priv->widgets, json,
-                                     FIELD_QUEUE_POSITION, NULL, 0,
-                                     INT_MAX, 1);
+        w = trg_json_widget_spin_int_new(&priv->widgets, json,
+                                         FIELD_QUEUE_POSITION, NULL, 0,
+                                         INT_MAX, 1);
         hig_workarea_add_row(t, &row, _("Queue Position:"), w, w);
     }
 
@@ -432,15 +432,15 @@ static GtkWidget *trg_props_limits_page_new(TrgTorrentPropsDialog * win,
                                    FIELD_DOWNLOAD_LIMITED,
                                    _("Limit download speed (KiB/s)"),
                                    NULL);
-    w = trg_json_widget_spin_new(&priv->widgets, json,
-                                 FIELD_DOWNLOAD_LIMIT, tb, 0, INT_MAX, 1);
+    w = trg_json_widget_spin_int_new(&priv->widgets, json,
+                                     FIELD_DOWNLOAD_LIMIT, tb, 0, INT_MAX, 1);
     hig_workarea_add_row_w(t, &row, tb, w, NULL);
 
     tb = trg_json_widget_check_new(&priv->widgets, json,
                                    FIELD_UPLOAD_LIMITED,
                                    _("Limit upload speed (KiB/s)"), NULL);
-    w = trg_json_widget_spin_new(&priv->widgets, json, FIELD_UPLOAD_LIMIT,
-                                 tb, 0, INT_MAX, 1);
+    w = trg_json_widget_spin_int_new(&priv->widgets, json, FIELD_UPLOAD_LIMIT,
+                                     tb, 0, INT_MAX, 1);
     hig_workarea_add_row_w(t, &row, tb, w, NULL);
 
     hig_workarea_add_section_title(t, &row, _("Seeding"));
@@ -453,9 +453,9 @@ static GtkWidget *trg_props_limits_page_new(TrgTorrentPropsDialog * win,
                              torrent_get_seed_ratio_mode(json));
     hig_workarea_add_row(t, &row, _("Seed ratio mode:"), w, NULL);
 
-    w = trg_json_widget_spin_new(&priv->widgets, json,
-                                 FIELD_SEED_RATIO_LIMIT, NULL, 0, INT_MAX,
-                                 0.2);
+    w = trg_json_widget_spin_double_new(&priv->widgets, json,
+                                        FIELD_SEED_RATIO_LIMIT, NULL, 0,
+                                        INT_MAX, 0.2);
     seed_ratio_mode_changed_cb(priv->seedRatioMode, w);
     g_signal_connect(G_OBJECT(priv->seedRatioMode), "changed",
                      G_CALLBACK(seed_ratio_mode_changed_cb), w);
@@ -463,8 +463,8 @@ static GtkWidget *trg_props_limits_page_new(TrgTorrentPropsDialog * win,
 
     hig_workarea_add_section_title(t, &row, _("Peers"));
 
-    w = trg_json_widget_spin_new(&priv->widgets, json, FIELD_PEER_LIMIT,
-                                 NULL, 0, INT_MAX, 5);
+    w = trg_json_widget_spin_int_new(&priv->widgets, json, FIELD_PEER_LIMIT,
+                                     NULL, 0, INT_MAX, 5);
     hig_workarea_add_row(t, &row, _("Peer limit:"), w, w);
 
     return t;
